@@ -8,6 +8,7 @@
 
 BEGIN { $| = 1; print "1..last_test_to_print\n"; }
 END {print "not ok 1\n" unless $loaded;}
+use Tk;
 use JListbox;
 $loaded = 1;
 print "ok 1\n";
@@ -18,17 +19,18 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
-# JListbox test program
-# JListbox test program
-use Tk;
-use JListbox;
+require Tk::DialogBox;
 
 $mw = MainWindow->new;
-$jlb = $mw->JListbox(-justify=>'right', -width=>75);
+
+$jlb = $mw->JListbox(-justify=>'center', -width=>75, -popupmenu=>1);
+
 $jlb->pack(-expand=>1, -fill=>'x');
 
-$jlb->insert('end',"Hello World");
-$jlb->insert('end',"Hello Once Again");
+$jlb->insert('end',"Hello World!");
+$jlb->insert('end',"How are you");
+$jlb->insert('end',"ABCDEFG");
+$jlb->insert('end',"12345");
 
 $cButton = $mw->Button(-text=>"Center Text", -command=>sub{
    $jlb->configure(-justify=>'center')}
@@ -46,3 +48,7 @@ $eButton->pack;
 
 MainLoop;
 
+
+
+
+
